/* header file for scsi_cmds.c */

extern unsigned char *bufferTOC;
extern unsigned char *cmd;
extern int adjust_ssize;

int allow_atapi(int new);
int SCSI_emulated_ATAPI_on( void );
unsigned char *Inquiry ( void );
int TestForMedium ( void );
void SpeedSelectSCSIMMC (unsigned speed);
void SpeedSelectSCSIYamaha (unsigned speed);
void SpeedSelectSCSISony (unsigned speed);
void SpeedSelectSCSIPhilipsCDD2600 (unsigned speed);
void SpeedSelectSCSINEC (unsigned speed);
void SpeedSelectSCSIToshiba (unsigned speed);
void ReadCddaMMC12 (unsigned char *p, long lSector, unsigned long SectorBurstVal, int with_errorblockflags );
void ReadCdda12 (unsigned char *p, long lSector, unsigned long SectorBurstVal, int with_errorblockflags );
void ReadCdda10 (unsigned char *p, long lSector, unsigned long SectorBurstVal, int with_errorblockflags );
void ReadStandard (unsigned char *p, long lSector, unsigned long SectorBurstVal, int with_errorblockflags );
unsigned ReadTocCdrSCSI ( TOC *toc );
unsigned ReadTocSCSI ( TOC *toc );
unsigned ReadFirstSessionTOCSony ( unsigned tracks );
unsigned ReadFirstSessionTOCMMC ( unsigned tracks );
void ReadTocTextSCSI ( void );
int Play_atSCSI ( unsigned int from_sector, unsigned int sectors);
void EnableCddaModeSelect (int fAudioMode);
int set_sectorsize (unsigned int secsize, int set_density);
unsigned int
get_orig_sectorsize(unsigned char *m4, unsigned char *m10,
                    unsigned char *m11);
unsigned int get_mmc(void);
int is_mmc(void);

extern unsigned char density;
extern unsigned char orgmode4;
extern unsigned char orgmode10, orgmode11;

